#coding=utf-8
#import a.aa.module_AA
#a.aa.module_AA.fun_AA()
#from a.aa import module_AA
#module_AA.fun_AA()
#from a.aa.module_AA import fun_AA
#fun_AA()
import math
import a
print(a.math.pi)
print(id(math))
print(id(a.math))

from a import *#实际上是导入__init__里面的__all__方法
module_A.fun_A()


#coding=gbk
from distutils.core import setup
setup(
    name="1_super_test",#对外模块的名字
    version="1.0",#版本号
    decription="这是一个对外发布的模块",#描述
    author="胡琳",#作者
    author_email="lily345543@126.com",
    py_modules=["super.module_B1","super.module_B2"])#要发布的模块